window.Gleam.initSearch([{"doc":"ranger","title":"ranger","content":"![ranger](https://raw.githubusercontent.com/massivefermion/ranger/main/banner.jpg)\n\n[![Package Version](https://img.shields.io/hexpm/v/ranger)](https://hex.pm/packages/ranger)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/ranger/)\n\n# ranger\n\ncreate ranges over any type\n\n## Quick start\n\n```sh\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add ranger\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/ranger&gt;.\n","url":"index.html"},{"doc":"ranger","title":"create","content":"pub fn create(\n  validate validate: fn(a) -&gt; Bool,\n  negate_step negate_step: fn(b) -&gt; b,\n  add add: fn(a, b) -&gt; a,\n  compare compare: fn(a, a) -&gt; Order,\n) -&gt; fn(a, a, b) -&gt; Result(Iterator(a), Nil)\n returns a function that can be used to create a range\n\n ## Examples\n\n \n &gt; let range =\n &gt;  create(\n &gt;    validate: fn(a) { string.length(a) == 1 },\n &gt;    negate_step: fn(s) { -1 * s },\n &gt;    add: fn(a: String, b: Int) {\n &gt;      let [code] = string.to_utf_codepoints(a)\n &gt;      let int_code = string.utf_codepoint_to_int(code)\n &gt;      let new_int_code = int_code + b\n &gt;      let assert Ok(new_code) = string.utf_codepoint(new_int_code)\n &gt;      string.from_utf_codepoints([new_code])\n &gt;    },\n &gt;    compare: string.compare,\n &gt;  )\n\n &gt; range(&quot;ab&quot;, &quot;e&quot;, 1)\n Error(Nil)\n\n &gt; let assert Ok(a_to_e) = range(&quot;a&quot;, &quot;e&quot;, 1)\n &gt; a_to_e |&gt; iterator.to_list\n [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;, &quot;d&quot;, &quot;e&quot;]\n \n &gt; let assert Ok(z_to_p) = range(&quot;z&quot;, &quot;p&quot;, 1)\n &gt; z_to_p |&gt; iterator.to_list\n [&quot;z&quot;, &quot;y&quot;, &quot;x&quot;, &quot;w&quot;, &quot;v&quot;, &quot;u&quot;, &quot;t&quot;, &quot;s&quot;, &quot;r&quot;, &quot;q&quot;, &quot;p&quot;]\n\n &gt; let assert Ok(z_to_p) = range(&quot;z&quot;, &quot;p&quot;, -2)\n &gt; z_to_p |&gt; iterator.to_list\n [&quot;z&quot;, &quot;x&quot;, &quot;v&quot;, &quot;t&quot;, &quot;r&quot;, &quot;p&quot;]\n\n &gt; let assert Ok(z_to_p) = range(&quot;z&quot;, &quot;p&quot;, 3)\n &gt; z_to_p |&gt; iterator.to_list\n [&quot;z&quot;, &quot;w&quot;, &quot;t&quot;, &quot;q&quot;]\n \n\n\n \n &gt; let range =\n &gt;    create(\n &gt;      validate: fn(_) { True },\n &gt;      negate_step: fn(s) { -1.0 *. s },\n &gt;      add: fn(a, b) { a +. b },\n &gt;      compare: float.compare,\n &gt;    )\n\n &gt; let assert Ok(weird_step_case) = range(1.25, 4.5, -0.5)\n &gt; weird_step_case |&gt; iterator.to_list\n [1.25, 1.75, 2.25, 2.75, 3.25, 3.75, 4.25]\n \n &gt; let assert Ok(single_item_case) = range(1.25, 1.25, -0.25)\n &gt; single_item_case |&gt; iterator.to_list\n [1.25]\n\n &gt; let assert Ok(zero_step_case) = range(2.5, 5.0, 0)\n &gt; zero_step_case |&gt; iterator.to_list\n [2.5]\n \n\nSynonyms:\nranger.create\nranger create","url":"ranger.html#create"},{"doc":"ranger","title":"create_infinite","content":"pub fn create_infinite(\n  validate validate: fn(a) -&gt; Bool,\n  add add: fn(a, b) -&gt; a,\n  compare compare: fn(a, a) -&gt; Order,\n) -&gt; fn(a, b) -&gt; Result(Iterator(a), Nil)\n returns a function that can be used to create an infinite range\n\n should be used carefully because careless use of infinite iterators could crash your app\n\n ## Examples\n\n \n &gt; let range =\n &gt;  create_infinite(\n &gt;    validate: fn(a) { string.length(a) == 1 },\n &gt;    add: fn(a: String, b: Int) {\n &gt;      let [code] = string.to_utf_codepoints(a)\n &gt;      let int_code = string.utf_codepoint_to_int(code)\n &gt;      let new_int_code = int_code + b\n &gt;      let assert Ok(new_code) = string.utf_codepoint(new_int_code)\n &gt;      string.from_utf_codepoints([new_code])\n &gt;    },\n &gt;    compare: string.compare,\n &gt;   )\n\n &gt; let assert Ok(from_a) = range(&quot;a&quot;, 1)\n &gt; from_a |&gt; iterator.take(26) |&gt; iterator.to_list\n [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;, &quot;d&quot;, &quot;e&quot;, &quot;f&quot;, &quot;g&quot;, &quot;h&quot;, &quot;i&quot;, &quot;j&quot;, &quot;k&quot;, &quot;l&quot;, &quot;m&quot;, &quot;n&quot;,\n   &quot;o&quot;, &quot;p&quot;, &quot;q&quot;, &quot;r&quot;, &quot;s&quot;, &quot;t&quot;, &quot;u&quot;, &quot;v&quot;, &quot;w&quot;, &quot;x&quot;, &quot;y&quot;, &quot;z&quot;]\n \nSynonyms:\nranger.create_infinite\nranger create_infinite","url":"ranger.html#create_infinite"},{"doc":"ranger","title":"ranger","content":"","url":"ranger.html"}]);